==> ncbi-blast+_2.12.0+ds.orig.tar.xz: ncbi-blast-2.12.0+-src/c++/include/algo/blast/blastinput/tblastn_args.hpp <==
/*  $Id: tblastn_args.hpp 631557 2021-05-19 13:52:41Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author: Christiam Camacho
 *
 */

/** @file tblastn_args.hpp
 * Main argument class for TBLASTN application
 */

#ifndef ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP
#define ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP

#include <algo/blast/blastinput/blast_args.hpp>

BEGIN_NCBI_SCOPE
BEGIN_SCOPE(blast)

/// Handles command line arguments for Tblastn binary
class NCBI_BLASTINPUT_EXPORT CTblastnAppArgs : public CBlastAppArgs
{
public:
    /// Constructor
    CTblastnAppArgs();

    /// Get the PSSM
    /// @return non-NULL PSSM if it's psi-tblastn
    CRef<objects::CPssmWithParameters> GetInputPssm() const;

    /// Set the PSSM from the saved search strategy 
    void SetInputPssm(CRef<objects::CPssmWithParameters> pssm);

    /// Get the query batch size
    virtual int GetQueryBatchSize() const;

protected:
    virtual CRef<CBlastOptionsHandle>
    x_CreateOptionsHandle(CBlastOptions::EAPILocality locality,
                          const CArgs& args);

    /// PSI-BLAST specific argument class (for psi-tblastn)
    /// @note this program is added to tblastn because all options for tblastn
    /// apply to psitblastn (i.e.: db genetic code, cannot be iterated)
    CRef<CPsiBlastArgs> m_PsiBlastArgs;
};

class NCBI_BLASTINPUT_EXPORT CTblastnNodeArgs : public CTblastnAppArgs
{
public:
    /// Constructor
    CTblastnNodeArgs(const string & input);

    /// @inheritDoc
    virtual int GetQueryBatchSize() const;

    /// Get the input stream
    virtual CNcbiIstream& GetInputStream();

    /// Get the output stream
    virtual CNcbiOstream& GetOutputStream();

    CNcbiOstrstream & GetOutputStrStream() { return m_OutputStream; }

    virtual ~CTblastnNodeArgs();

protected:
    /// @inheritDoc
    virtual CRef<CBlastOptionsHandle>
    x_CreateOptionsHandle(CBlastOptions::EAPILocality locality, const CArgs& args);

private :
    CNcbiOstrstream m_OutputStream;
    CNcbiIstrstream * m_InputStream;
};

END_SCOPE(blast)
END_NCBI_SCOPE

#endif  /* ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP */

==> ncbi-blast+_2.16.0+ds.orig.tar.xz: ncbi-blast-2.16.0+-src/c++/include/algo/blast/blastinput/tblastn_args.hpp <==
/*  $Id: tblastn_args.hpp 636725 2021-08-30 13:30:53Z fongah2 $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author: Christiam Camacho
 *
 */

/** @file tblastn_args.hpp
 * Main argument class for TBLASTN application
 */

#ifndef ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP
#define ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP

#include <algo/blast/blastinput/blast_args.hpp>

BEGIN_NCBI_SCOPE
BEGIN_SCOPE(blast)

/// Handles command line arguments for Tblastn binary
class NCBI_BLASTINPUT_EXPORT CTblastnAppArgs : public CBlastAppArgs
{
public:
    /// Constructor
    CTblastnAppArgs();

    /// Get the PSSM
    /// @return non-NULL PSSM if it's psi-tblastn
    CRef<objects::CPssmWithParameters> GetInputPssm() const;

    /// Set the PSSM from the saved search strategy 
    void SetInputPssm(CRef<objects::CPssmWithParameters> pssm);

    /// Get the query batch size
    virtual int GetQueryBatchSize() const;

protected:
    virtual CRef<CBlastOptionsHandle>
    x_CreateOptionsHandle(CBlastOptions::EAPILocality locality,
                          const CArgs& args);

    /// PSI-BLAST specific argument class (for psi-tblastn)
    /// @note this program is added to tblastn because all options for tblastn
    /// apply to psitblastn (i.e.: db genetic code, cannot be iterated)
    CRef<CPsiBlastArgs> m_PsiBlastArgs;
};

class NCBI_BLASTINPUT_EXPORT CTblastnNodeArgs : public CTblastnAppArgs
{
public:
    /// Constructor
    CTblastnNodeArgs(const string & input);

    /// @inheritDoc
    virtual int GetQueryBatchSize() const;

    /// Get the input stream
    virtual CNcbiIstream& GetInputStream();

    /// Get the output stream
    virtual CNcbiOstream& GetOutputStream();

    CNcbiStrstream & GetOutputStrStream() { return m_OutputStream; }

    virtual ~CTblastnNodeArgs();

protected:
    /// @inheritDoc
    virtual CRef<CBlastOptionsHandle>
    x_CreateOptionsHandle(CBlastOptions::EAPILocality locality, const CArgs& args);

private :
    CNcbiStrstream m_OutputStream;
    CNcbiIstrstream * m_InputStream;
};

END_SCOPE(blast)
END_NCBI_SCOPE

#endif  /* ALGO_BLAST_BLASTINPUT___TBLASTN_ARGS__HPP */
